{% extends "basic/layout.html" %}
{% set css_files = css_files + ['_static/tweaks.css'] %}

{% block sidebar2 %}
<div class="sphinxsidebar">
    <div class="sphinxsidebarwrapper">
        {%- if not embedded %}{% if not theme_nosidebar|tobool %}
          {%- block sidebarlogo %}
          {%- if logo %}
            <p class="logo"><a href="{{ pathto(master_doc) }}">
              <img class="logo" src="{{ pathto('_static/' + logo, 1) }}" alt="Logo"/>
            </a></p>
          {%- endif %}
          {%- endblock %}
          {%- block sidebartoc %}
          {%- if display_toc %}
            <h3><a href="{{ pathto(master_doc) }}">{{ _('Table Of Contents') }}</a></h3>
            {{ toc }}
          {%- endif %}
          {%- endblock %}
          {%- block sidebarrel %}
          {%- if prev %}
            <h4>{{ _('Previous topic') }}</h4>
            <p class="topless"><a href="{{ prev.link|e }}"
                                  title="{{ _('previous chapter') }}">{{ prev.title }}</a></p>
          {%- endif %}
          {%- if next %}
            <h4>{{ _('Next topic') }}</h4>
            <p class="topless"><a href="{{ next.link|e }}"
                                  title="{{ _('next chapter') }}">{{ next.title }}</a></p>
          {%- endif %}
          {%- endblock %}
          {%- block otherversions %}
            {%- if other_versions %}
              <h3>{{ _('Other Versions') }}</h3>
              <ul class="this-page-menu">
                  <li><a href="{{ pathto(master_doc) }}" rel="nofollow">Current</a></li>
                  {%- for ver in other_versions: %}
                    <li><a href="{{ pathto(ver, 1) }}" rel="nofollow">{{ ver }}</a></li>
                  {%- endfor %}
              </ul>
            {%- endif %}
          {%- endblock %}
          {%- block projectsource %}
            {%- if cgit_link %}
            <h3>{{ _('Project Source') }}</h3>
            <ul class="this-page-menu">
              <li><a href="{{cgit_link}}"
                     rel="nofollow">{{ _('Project Source') }}</a></li>
            </ul>
            {%- endif %}
          {%- endblock %}
          {%- block sidebarsourcelink %}
          {%- if show_source and has_source and sourcename %}
            <h3>{{ _('This Page') }}</h3>
            <ul class="this-page-menu">
              <li><a href="{{ pathto('_sources/' + sourcename, true)|e }}"
                     rel="nofollow">{{ _('Show Source') }}</a></li>
            </ul>
          {%- endif %}
          {%- endblock %}
          {%- if customsidebar %}
          {% include customsidebar %}
          {%- endif %}
          {%- block sidebarsearch %}
          {%- if pagename != "search" %}
          <div id="searchbox" style="display: none">
            <h3>{{ _('Quick search') }}</h3>
              <form class="search" action="{{ pathto('search') }}" method="get">
                <input type="text" name="q" size="18" />
                <input type="submit" value="{{ _('Go') }}" />
                <input type="hidden" name="check_keywords" value="yes" />
                <input type="hidden" name="area" value="default" />
              </form>
              <p class="searchtip" style="font-size: 90%">
              {{ _('Enter search terms or a module, class or function name.') }}
              </p>
          </div>
          <script type="text/javascript">$('#searchbox').show(0);</script>
          {%- endif %}
          {%- endblock %}
      {%- endif %}{% endif %}
    </div>
</div>
{% endblock %}

{% block relbar1 %}{% endblock relbar1 %}

{% block header %}
  <div id="header">
    <h1 id="logo"><a href="http://www.openstack.org/">OpenStack</a></h1>
    <ul id="navigation">
      {% block header_navigation %}
      <li><a href="http://www.openstack.org/" title="Go to the Home page" class="link">Home</a></li>
      <li><a href="http://www.openstack.org/projects/" title="Go to the OpenStack Projects page">Projects</a></li>
      <li><a href="http://www.openstack.org/user-stories/" title="Go to the User Stories page" class="link">User Stories</a></li>
      <li><a href="http://www.openstack.org/community/" title="Go to the Community page" class="link">Community</a></li>
      <li><a href="http://www.openstack.org/blog/" title="Go to the OpenStack Blog">Blog</a></li>
      <li><a href="http://wiki.openstack.org/" title="Go to the OpenStack Wiki">Wiki</a></li>
      <li><a href="http://docs.openstack.org/" title="Go to OpenStack Documentation" class="current">Documentation</a></li>
      {% endblock %}
    </ul>
  </div>
{% endblock %}

{% block footer %}
{{ super() }}
<script type="text/javascript">
var gaJsHost = (("https:" == document.location.protocol) ? "https://ssl." : "http://www.");
document.write(unescape("%3Cscript src='" + gaJsHost + "google-analytics.com/ga.js' type='text/javascript'%3E%3C/script%3E"));
</script>
<script type="text/javascript">
try {
//Tracking docs.openstack.org/developer/<projectname> only
//The URL is built from the project variable in conf.py
var pageTracker = _gat._getTracker("UA-17511903-1");
pageTracker._setCookiePath("/developer/{{ project }}");
pageTracker._trackPageview();
} catch(err) {}</script>
{% endblock %}
